@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9861 2017-04-14 16:33:10Z David $
+# $Id: __init__.py 9889 2017-04-22 14:24:50Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-04-15 00:33:10 +0800 (Sat, 15 Apr 2017) $
-# $Revision: 9861 $
+# $Date: 2017-04-22 22:24:50 +0800 (Sat, 22 Apr 2017) $
+# $Revision: 9889 $
 
 import os
 import sys
@@ -497,9 +497,11 @@ def attachSettings(settingsDict):
 
         if settingsDict['SERVER_MODE'] == settingsDict['DEVELOPMENT']:
             warnings.warn("%s '%s'" % (
-                colored("Cannot locate STATIC_URL", 'yellow', attrs=['bold']),
-                colored("Please run server with arg --insecure under the \
-                development mode if DEBUG=False.", 'cyan', attrs=['bold'])))
+                colored("If you want to serve static_files", 'yellow', 
+                        attrs=['bold']),
+                colored("Please run server with arg --insecure under the "
+                        "development mode if DEBUG=False.", 'cyan', 
+                        attrs=['bold'])))
     else:
         staticDefaults = {
             'STATICFILES_DIRS': (
@@ -740,3 +742,18 @@ def attachSettings(settingsDict):
     if settingsDict['SERVER_MODE'] == settingsDict['DEVELOPMENT']:
         Patch.attachDebugSettings(settingsDict)
     #=========================================================================
+    # Attach Iuno Urls
+    def attachIunoUrls(settings, urlpatterns):
+        """
+        Attach Iuno related urlpatterns.
+        It must be called in urls.py by passing urlpatterns.
+    
+        @param settings Django project's settings module.
+        @param urlpatterns urlpatterns in urls.py.
+        """
+
+        from django.conf.urls import url, include, patterns
+
+        urlpatterns += patterns('',
+            (r'^i18n/', include('django.conf.urls.i18n')),
+        )
